==> hledger-web-1.5-38-armv7h.pkg.tar.xz: usr/share/haskell/register/hledger-web.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-web
version: 1.5
id: hledger-web-1.5-8FVVrRM9a12AUJQevyN4P0
key: hledger-web-1.5-8FVVrRM9a12AUJQevyN4P0
license: GPL-3
maintainer: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Web interface for the hledger accounting tool
description:
    This is hledger'\''s web interface.
    It provides a more user-friendly and collaborative UI than the
    command-line or curses-style interfaces.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
author: Simon Michael <simon@joyful.com>
exposed: True
indefinite: False
exposed-modules:
    Application Foundation Handler.AddForm Handler.Common
    Handler.JournalR Handler.RegisterR Handler.RootR Handler.SidebarR
    Handler.Utils Hledger.Web Hledger.Web.Main Hledger.Web.WebOptions
    Import Settings Settings.Development Settings.StaticFiles
hidden-modules: Paths_hledger_web
abi: f1d02087e0ac40f2863d85fa8f25aaad
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hledger-web-1.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/hledger-web-1.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger-web
hs-libraries: HShledger-web-1.5-8FVVrRM9a12AUJQevyN4P0
depends:
    HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4 base-4.10.1.0
    base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA
    blaze-html-0.9.0.1-2Wxj0X1c4OOA0Fs6NGHGGN
    blaze-markup-0.8.2.0-JO1Oy9jYgbGFSxqAItqjWc bytestring-0.10.8.2
    clientsession-0.9.1.2-2lGNg8vCcWM7wEOsbP5eJc
    cmdargs-0.10.20-2F76lFHX0FM7iO7H1ddZ4v
    conduit-extra-1.2.3.2-HqvxZXqsE5uH7cTVcctTVX
    data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr directory-1.3.0.2
    filepath-1.4.1.2 hjsmin-0.2.0.2-IFqXHw85N4f4E0sHXVdI8c
    hledger-1.5-BfAJwsrJnMlJ3of5vIGgyx
    hledger-lib-1.5-9Ti4gLnUgFJBPZ5dFhGWRN
    http-client-0.5.9-Azgv8Xc1NGFByFCcfPecMM
    http-conduit-2.2.4-2aF49GeTLK71X1jnMRPiFc
    json-0.9.1-ERegjITqAKD3AfIvde7JRa
    megaparsec-6.4.0-3L9oPlo4fwnK4OAnu5pCAg
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7
    safe-0.3.15-EroU33EYnr02fGSZYGiX97
    shakespeare-2.0.14.1-F9ZMtelONK91m6N6iRt61y
    template-haskell-2.12.0.0 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    time-1.8.0.2 transformers-0.5.2.0
    wai-3.2.1.1-12WuVnNjQfQ3f2A19Ra0dE
    wai-extra-3.0.22.0-4wfjOoKP6kq5VF3xTGUawr
    wai-handler-launch-3.0.2.3-JliJbehzd7EGmj8Z6qCdzw
    warp-3.2.15-BfNfITjtnouGil3XMpXCZm
    yaml-0.8.28-BxpNH3p0KeeJ7JEMiXGfSc
    yesod-1.4.5-7PuStE3spK5AOuy2AOHZLg
    yesod-core-1.4.37.3-1TCEr6QHBxU7z2BW9PY1c
    yesod-form-1.4.16-1hlb1t6BQumAC6RnXjM3Y9
    yesod-static-1.5.3.1-HJZu1F6lBZ11dsrbvbhEKq
abi-depends: HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4=cc02d4bbc4678b779cddf8743bb71eea
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=b23a246a62afd271167dd1ea1b77583b
             blaze-html-0.9.0.1-2Wxj0X1c4OOA0Fs6NGHGGN=d4749ddd32d1bff43101b58ffdfa6b64
             blaze-markup-0.8.2.0-JO1Oy9jYgbGFSxqAItqjWc=8e9b9ff2cdf9e89a23593b7f85e59200
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             clientsession-0.9.1.2-2lGNg8vCcWM7wEOsbP5eJc=2cf38df139b5a2f2e61d0c0b640473a7
             cmdargs-0.10.20-2F76lFHX0FM7iO7H1ddZ4v=3df23fc9720f306ed55f4a644655f521
             conduit-extra-1.2.3.2-HqvxZXqsE5uH7cTVcctTVX=cad73d001def538e4783a64d0bb32d79
             data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr=0186e0f4b96bc201d2baef8ade597d90
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             hjsmin-0.2.0.2-IFqXHw85N4f4E0sHXVdI8c=fc3fe993fea3167c57e2092446983062
             hledger-1.5-BfAJwsrJnMlJ3of5vIGgyx=3c813d35d915825fdb9185e74d6d7f57
             hledger-lib-1.5-9Ti4gLnUgFJBPZ5dFhGWRN=30d49157be6bd7bb033357060471a6fc
             http-client-0.5.9-Azgv8Xc1NGFByFCcfPecMM=3f0d0d78fad058647ea21be363f07f5d
             http-conduit-2.2.4-2aF49GeTLK71X1jnMRPiFc=9faddc359714f17ccc9cc2f3a39a1a38
             json-0.9.1-ERegjITqAKD3AfIvde7JRa=b6dfbaf75666813c35e9c570dc0f6663
             megaparsec-6.4.0-3L9oPlo4fwnK4OAnu5pCAg=d97345b8996165d251814b52fb9452d6
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7=5b8a6db8c81629fde3a12212030372e3
             safe-0.3.15-EroU33EYnr02fGSZYGiX97=604c7b7c109a34b58d71795df287548a
             shakespeare-2.0.14.1-F9ZMtelONK91m6N6iRt61y=e81dfb107090b7a1f4db570c5496a2f4
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             wai-3.2.1.1-12WuVnNjQfQ3f2A19Ra0dE=73d1afed3c80663ac957a99a7f1e4642
             wai-extra-3.0.22.0-4wfjOoKP6kq5VF3xTGUawr=bf0a514c71060ca649d5ac38f3e8c93c
             wai-handler-launch-3.0.2.3-JliJbehzd7EGmj8Z6qCdzw=2547ef83d6f013d2d984d431a4a37bb8
             warp-3.2.15-BfNfITjtnouGil3XMpXCZm=794b2c017d7606aedc6ba48dcffa9768
             yaml-0.8.28-BxpNH3p0KeeJ7JEMiXGfSc=82ceb1cce856425da6a2fcfb440eb4bc
             yesod-1.4.5-7PuStE3spK5AOuy2AOHZLg=bdd5442143c085d515852efd4b3e0693
             yesod-core-1.4.37.3-1TCEr6QHBxU7z2BW9PY1c=a84be6c3d5eaeb50a8be558f1179dc76
             yesod-form-1.4.16-1hlb1t6BQumAC6RnXjM3Y9=1c6d6980959a70f17dcc4a4904a8884e
             yesod-static-1.5.3.1-HJZu1F6lBZ11dsrbvbhEKq=df2087ab394b421243b12a46ff374e79
haddock-interfaces: /usr/share/doc/hledger-web/html/hledger-web.haddock
haddock-html: /usr/share/doc/hledger-web/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hledger-web-1.5-42-armv7h.pkg.tar.xz: usr/share/haskell/register/hledger-web.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-web
version: 1.5
id: hledger-web-1.5-BzYevUpCIAcKesn9sxmbbx
key: hledger-web-1.5-BzYevUpCIAcKesn9sxmbbx
license: GPL-3
maintainer: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Web interface for the hledger accounting tool
description:
    This is hledger'\''s web interface.
    It provides a more user-friendly and collaborative UI than the
    command-line or curses-style interfaces.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
author: Simon Michael <simon@joyful.com>
exposed: True
indefinite: False
exposed-modules:
    Application Foundation Handler.AddForm Handler.Common
    Handler.JournalR Handler.RegisterR Handler.RootR Handler.SidebarR
    Handler.Utils Hledger.Web Hledger.Web.Main Hledger.Web.WebOptions
    Import Settings Settings.Development Settings.StaticFiles
hidden-modules: Paths_hledger_web
abi: 5a8d5bf1b982f888928d2afcdaeed3a0
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hledger-web-1.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/hledger-web-1.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger-web
hs-libraries: HShledger-web-1.5-BzYevUpCIAcKesn9sxmbbx
depends:
    HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4 base-4.10.1.0
    base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA
    blaze-html-0.9.0.1-2Wxj0X1c4OOA0Fs6NGHGGN
    blaze-markup-0.8.2.0-JO1Oy9jYgbGFSxqAItqjWc bytestring-0.10.8.2
    clientsession-0.9.1.2-2lGNg8vCcWM7wEOsbP5eJc
    cmdargs-0.10.20-2F76lFHX0FM7iO7H1ddZ4v
    conduit-extra-1.2.3.2-HqvxZXqsE5uH7cTVcctTVX
    data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr directory-1.3.0.2
    filepath-1.4.1.2 hjsmin-0.2.0.2-IFqXHw85N4f4E0sHXVdI8c
    hledger-1.5-B4G2WTDC5Iy3XXA3lxukE0
    hledger-lib-1.5-9Ti4gLnUgFJBPZ5dFhGWRN
    http-client-0.5.10-2RNldYKn2g78bCCdUJAIlp
    http-conduit-2.2.4-IxWLxiVFOO7CKtnV6c0AX
    json-0.9.1-ERegjITqAKD3AfIvde7JRa
    megaparsec-6.4.0-3L9oPlo4fwnK4OAnu5pCAg
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7
    safe-0.3.15-EroU33EYnr02fGSZYGiX97
    shakespeare-2.0.14.1-F9ZMtelONK91m6N6iRt61y
    template-haskell-2.12.0.0 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    time-1.8.0.2 transformers-0.5.2.0
    wai-3.2.1.1-12WuVnNjQfQ3f2A19Ra0dE
    wai-extra-3.0.22.0-4wfjOoKP6kq5VF3xTGUawr
    wai-handler-launch-3.0.2.3-JliJbehzd7EGmj8Z6qCdzw
    warp-3.2.15-BfNfITjtnouGil3XMpXCZm
    yaml-0.8.28-BxpNH3p0KeeJ7JEMiXGfSc
    yesod-1.4.5-8E7xLZqoffFB7vJmfuDzvo
    yesod-core-1.4.37.3-1TCEr6QHBxU7z2BW9PY1c
    yesod-form-1.4.16-3CtS2XxBgLRHOUyv2DFIRa
    yesod-static-1.5.3.1-HJZu1F6lBZ11dsrbvbhEKq
abi-depends: HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4=cc02d4bbc4678b779cddf8743bb71eea
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=b23a246a62afd271167dd1ea1b77583b
             blaze-html-0.9.0.1-2Wxj0X1c4OOA0Fs6NGHGGN=d4749ddd32d1bff43101b58ffdfa6b64
             blaze-markup-0.8.2.0-JO1Oy9jYgbGFSxqAItqjWc=8e9b9ff2cdf9e89a23593b7f85e59200
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             clientsession-0.9.1.2-2lGNg8vCcWM7wEOsbP5eJc=2cf38df139b5a2f2e61d0c0b640473a7
             cmdargs-0.10.20-2F76lFHX0FM7iO7H1ddZ4v=3df23fc9720f306ed55f4a644655f521
             conduit-extra-1.2.3.2-HqvxZXqsE5uH7cTVcctTVX=cad73d001def538e4783a64d0bb32d79
             data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr=0186e0f4b96bc201d2baef8ade597d90
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             hjsmin-0.2.0.2-IFqXHw85N4f4E0sHXVdI8c=fc3fe993fea3167c57e2092446983062
             hledger-1.5-B4G2WTDC5Iy3XXA3lxukE0=b2417fa0795b7d1323b828b493b57472
             hledger-lib-1.5-9Ti4gLnUgFJBPZ5dFhGWRN=30d49157be6bd7bb033357060471a6fc
             http-client-0.5.10-2RNldYKn2g78bCCdUJAIlp=130e48f58092bf4612ede4d09e1c54bb
             http-conduit-2.2.4-IxWLxiVFOO7CKtnV6c0AX=790b7853e94d3834094e07505f970450
             json-0.9.1-ERegjITqAKD3AfIvde7JRa=b6dfbaf75666813c35e9c570dc0f6663
             megaparsec-6.4.0-3L9oPlo4fwnK4OAnu5pCAg=d97345b8996165d251814b52fb9452d6
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7=5b8a6db8c81629fde3a12212030372e3
             safe-0.3.15-EroU33EYnr02fGSZYGiX97=604c7b7c109a34b58d71795df287548a
             shakespeare-2.0.14.1-F9ZMtelONK91m6N6iRt61y=e81dfb107090b7a1f4db570c5496a2f4
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             wai-3.2.1.1-12WuVnNjQfQ3f2A19Ra0dE=73d1afed3c80663ac957a99a7f1e4642
             wai-extra-3.0.22.0-4wfjOoKP6kq5VF3xTGUawr=bf0a514c71060ca649d5ac38f3e8c93c
             wai-handler-launch-3.0.2.3-JliJbehzd7EGmj8Z6qCdzw=2547ef83d6f013d2d984d431a4a37bb8
             warp-3.2.15-BfNfITjtnouGil3XMpXCZm=794b2c017d7606aedc6ba48dcffa9768
             yaml-0.8.28-BxpNH3p0KeeJ7JEMiXGfSc=82ceb1cce856425da6a2fcfb440eb4bc
             yesod-1.4.5-8E7xLZqoffFB7vJmfuDzvo=bef27fddcd5cdb2538b662bb18d4b660
             yesod-core-1.4.37.3-1TCEr6QHBxU7z2BW9PY1c=a84be6c3d5eaeb50a8be558f1179dc76
             yesod-form-1.4.16-3CtS2XxBgLRHOUyv2DFIRa=5b457dee7ede99b09fb7f0b61c4d30dd
             yesod-static-1.5.3.1-HJZu1F6lBZ11dsrbvbhEKq=df2087ab394b421243b12a46ff374e79
haddock-interfaces: /usr/share/doc/hledger-web/html/hledger-web.haddock
haddock-html: /usr/share/doc/hledger-web/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
